summaryrefslogtreecommitdiffstats
path: root/generic/tclInt.h
diff options
context:
space:
mode:
authorMiguel Sofer <miguel.sofer@gmail.com>2003-09-23 14:48:49 (GMT)
committerMiguel Sofer <miguel.sofer@gmail.com>2003-09-23 14:48:49 (GMT)
commitc5da24d81b890f5969695988b3ce92f6c75ce97a (patch)
treec1c5e877182d7b31613204f3f1d225dec20b6557 /generic/tclInt.h
parent3573a596bac94e88ffcc47faf8602313fb41cd89 (diff)
downloadtcl-c5da24d81b890f5969695988b3ce92f6c75ce97a.zip
tcl-c5da24d81b890f5969695988b3ce92f6c75ce97a.tar.gz
tcl-c5da24d81b890f5969695988b3ce92f6c75ce97a.tar.bz2
* generic/tclExecute.c:
* generic/tclInt.h: changed the evaluation-stack addressing mode, from array-style to pointer-style; the catch stack and evaluation stack are now contiguous in memory. [Patch 457449]
Diffstat (limited to 'generic/tclInt.h')
-rw-r--r--generic/tclInt.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/generic/tclInt.h b/generic/tclInt.h
index 0da497b..2be3ad1 100644
--- a/generic/tclInt.h
+++ b/generic/tclInt.h
@@ -12,7 +12,7 @@
* See the file "license.terms" for information on usage and redistribution
* of this file, and for a DISCLAIMER OF ALL WARRANTIES.
*
- * RCS: @(#) $Id: tclInt.h,v 1.131 2003/08/11 13:26:13 dkf Exp $
+ * RCS: @(#) $Id: tclInt.h,v 1.132 2003/09/23 14:48:49 msofer Exp $
*/
#ifndef _TCLINT
@@ -873,9 +873,9 @@ typedef int (CompileHookProc) _ANSI_ARGS_((Tcl_Interp *interp,
typedef struct ExecEnv {
Tcl_Obj **stackPtr; /* Points to the first item in the
* evaluation stack on the heap. */
- int stackTop; /* Index of current top of stack; -1 when
- * the stack is empty. */
- int stackEnd; /* Index of last usable item in stack. */
+ Tcl_Obj **tosPtr; /* Points to current top of stack;
+ * (stackPtr-1) when the stack is empty. */
+ Tcl_Obj **endPtr; /* Points to last usable item in stack. */
Tcl_Obj *errorInfo;
Tcl_Obj *errorCode;
} ExecEnv;